@@ -396,7 +396,7 @@ for chains in models[1].get_chains():
 #common_atoms = common_chain_res(chain2[1], chain1[1]) # Between chains C and B
 
 
-def superimpose(chain1, chain2):
+def superimpose(chain1, chain2, apply=False):
     """
     Given a pair of chains, these are superimposed. The first input is the
     fixed chain, and the second one the moving chain. The rotran matrix is computed, applied to the
@@ -419,14 +419,16 @@ def superimpose(chain1, chain2):
 
         imposer = Superimposer()
         imposer.set_atoms(common_atoms[0], common_atoms[1])
-        imposer.apply(fixed_chain.get_atoms())
+        if apply == True:
+            imposer.apply(fixed_chain.get_atoms())
         print(imposer.rms)
 
     # If they are the same size
     else:
         imposer = Superimposer()
         imposer.set_atoms(fixed_atoms, moving_atoms)
-        imposer.apply(fixed_chain.get_atoms())
+        if apply == True:
+            imposer.apply(moving_m.get_atoms())
         print(imposer.rms)
 
 # Superimpose test
